California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 026 - AUTHORIZES NEW TYPES OF GAMBLING. INITIATIVE CONSTITUTIONAL AND STATUTORY AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1425966 | NO ON THE GAMBLING POWER GRAB: A COMMITTEE OF LOCAL COMMUNITY LEADERS, LICENSED CARD CLUBS AND THEIR EMPLOYEES, LAW ENFORCEMENT, AND LOCAL BUSINESSES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424396 | YES ON 26, NO ON 27 - COALITION FOR SAFE, RESPONSIBLE GAMING, SPONSORED BY CALIFORNIA INDIAN TRIBES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1439178 | NO ON 26 - TAXPAYERS AGAINST SPECIAL INTEREST MONOPOLIES, SPONSORED BY LICENSED CARD CLUBS | OPPOSE